/[Apache-SVN]/jakarta/commons/sandbox/i18n/trunk/src/java/org/apache/commons/i18n/bundles/MessageBundle.java
ViewVC logotype

Diff of /jakarta/commons/sandbox/i18n/trunk/src/java/org/apache/commons/i18n/bundles/MessageBundle.java

Parent Directory Parent Directory | Revision Log Revision Log | View Patch Patch

--- jakarta/commons/sandbox/i18n/trunk/src/java/org/apache/commons/i18n/bundles/MessageBundle.java	2005/05/06 10:19:21	168589
+++ jakarta/commons/sandbox/i18n/trunk/src/java/org/apache/commons/i18n/bundles/MessageBundle.java	2005/05/06 10:36:38	168590
@@ -62,10 +62,10 @@ public class MessageBundle extends TextB
 
     /**
      * @param locale The locale that is used to find the appropriate localized text 
      * @param defaultText The default text will be returned, if no entry with key <code>title</code> could be found in the message bundle identified by the given message identifier
      * @return returns the localized message entry with the key <code>title</code>
      */
-    public String getTitle(Locale locale, String defaultSummary) {
-        return getEntry(TITLE, defaultSummary, locale);
+    public String getTitle(Locale locale, String defaultTitle) {
+        return getEntry(TITLE, locale, defaultTitle);
     }
 }
\ No newline at end of file
@@ -62,10 +62,10 @@ public class MessageBundle extends TextB
     /**
      * @param locale The locale that is used to find the appropriate localized text 
-     * @param defaultText The default text will be returned, if no entry with key <code>title</code> could be found in the message bundle identified by the given message identifier
+     * @param defaultTitle The default text will be returned, if no entry with key <code>title</code> could be found in the message bundle identified by the given message identifier
      * @return returns the localized message entry with the key <code>title</code>
      */

 

infrastructure at apache.org
ViewVC Help
Powered by ViewVC 1.1.26